"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const cli_ux_1 = require("cli-ux");
const core_1 = require("@salesforce/core");
const base_1 = require("../../lib/base");
const api_client_1 = require("../../lib/api-client");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-functions', 'logout.functions');
class Login extends base_1.default {
    async run() {
        var _a, _b, _c;
        const { flags } = await this.parse(Login);
        const stateAggregator = await core_1.StateAggregator.getInstance();
        const token = (_a = stateAggregator.tokens.get('functions-bearer', true)) === null || _a === void 0 ? void 0 : _a.token;
        this.postParseHook(flags);
        cli_ux_1.cli.action.start(messages.getMessage('action.start'), '...', { stdout: true });
        if (!token) {
            throw new Error('Not authenticated.');
        }
        const client = new api_client_1.default({
            auth: token,
            apiUrl: (0, api_client_1.herokuClientApiUrl)(),
        });
        try {
            // get the sesion id
            const { data: session } = await client.get('/oauth/sessions');
            const sessionID = session[0].id;
            // delete the session
            await client.delete(`/oauth/sessions/${sessionID}`);
            // remove the token from state
            this.stateAggregator.tokens.unset(base_1.default.TOKEN_BEARER_KEY);
            await this.stateAggregator.tokens.write();
            cli_ux_1.cli.action.stop();
            return 'Logged out';
        }
        catch (err) {
            const error = err;
            if ((_b = error.message) === null || _b === void 0 ? void 0 : _b.includes('404')) {
                this.error(new Error('Session not found'));
            }
            if ((_c = error.message) === null || _c === void 0 ? void 0 : _c.includes('401')) {
                this.error(new Error('Invalid credentials'));
            }
            this.error(new Error(error.message));
        }
    }
}
exports.default = Login;
Login.summary = messages.getMessage('summary');
Login.examples = messages.getMessages('examples');
Login.flags = {};
